@@ -1,12 +1,17 @@
 # SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
 # SPDX-License-Identifier: MIT
 
+"""
+Basic `AHTx0` example test
+"""
+
 import time
 import board
 import adafruit_ahtx0
 
-# Create the sensor object using I2C
-sensor = adafruit_ahtx0.AHTx0(board.I2C())
+# Create sensor object, communicating over the board's default I2C bus
+i2c = board.I2C()
+sensor = adafruit_ahtx0.AHTx0(i2c)
 
 while True:
     print("\nTemperature: %0.1f C" % sensor.temperature)
